#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lua-arbitrary
version:              1.0.1.2
visibility:           public
id:                   lua-arbitrary-1.0.1.2-w4V2Q1L2pgAy5abeuBZvi
key:                  lua-arbitrary-1.0.1.2-w4V2Q1L2pgAy5abeuBZvi
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2026 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  50f15b0b0cc1c98fd203da4d9ddf79a2
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lua-arbitrary-1.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lua-arbitrary-1.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lua-arbitrary-1.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lua-arbitrary
hs-libraries:         HSlua-arbitrary-1.0.1.2-w4V2Q1L2pgAy5abeuBZvi
depends:
    QuickCheck-2.15.0.1-7YGuUScDosvJpuKkMIUiat base-4.18.2.1
    lua-2.3.4-DJNbWZiC3J24XU396IMoFZ

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

